@@ -1,12 +1,8 @@
 # import the necessary modules
-
 from pyees.variable import variable
 from pyees.fit import dummy_fit, pol_fit, lin_fit, exp_fit, pow_fit, logistic_fit, logistic_100_fit
 from pyees.readData import readData
 from pyees.prop import prop
 from pyees.solve import solve
-from pyees.unitSystem import getDicts
 
-
-knownUnits, knownCharacters, knownUnitsDict, knownPrefixes, baseUnit = getDicts()
     
\ No newline at end of file
