@@ -1,10 +1,8 @@
 import numpy as np
 try:
-    from pyees.unitSystem import _unitConversion
-    from pyees.__init__ import knownPrefixes, knownUnits, knownCharacters, knownUnitsDict, baseUnit
+    from unitSystem import _unitConversion, knownUnits, knownCharacters, knownUnitsDict, knownPrefixes, baseUnit
 except ImportError:
-    from unitSystem import _unitConversion, getDicts
-    knownUnits, knownCharacters, knownUnitsDict, knownPrefixes, baseUnit = getDicts()
+    from pyees.unitSystem import _unitConversion, knownUnits, knownCharacters, knownUnitsDict, knownPrefixes, baseUnit
 
 hyphen = '-'
 slash = '/'
@@ -270,7 +268,7 @@ class unit():
             parts = [unitStr[i+1:j] for i,j in zip(splits, splits[1:]+[None])]
             parts = [unit._formatUnit(part) for part in parts]
             if isinstance(parts, list):
-                return '/'.join(parts)
+                parts = unit(parts[0]) / unit(parts[1])
             return parts
         
         parts = unit._formatUnit(unitStr[order[0][0]+1: order[0][1]])
@@ -683,9 +681,5 @@ class unit():
         otherUpper, otherUpperPrefix, otherUpperExp, otherLower, otherLowerPrefix, otherLowerExp = self._getLists(self._SIBaseUnit)
         self._converterToSI = self._getConverter(otherUpper, otherUpperPrefix, otherUpperExp, otherLower, otherLowerPrefix, otherLowerExp)
 
-if __name__ == "__main__":
-    a = unit._formatUnit('(m-s2)2 / Hz')
-    print(a)
-    
 
 
